#[non_exhaustive]pub enum AnyComponentError {
Component {
name: String,
message: String,
},
NotInitialized(String),
}Expand description
Type-erased error from a boxed AnyComponent. The original typed
error is preserved as a string for log purposes; if callers need the
typed error they should downcast via AnyComponent::as_any_arc.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Component
The underlying component’s typed error, formatted as a string.
Fields
NotInitialized(String)
The component is registered but has not been initialized.