Module components

Module components 

Self-contained Component implementations that construct providers, stores, and adapters from JSON configuration.

Each wrapper type implements Component so it can be registered either directly via TypedFactory or through a FactoryRegistry using the convenience register_* functions or default_factory_registry.

Structs

ContextPipelineComponent
Component wrapper for ContextPipeline.
ContextPipelineConfig
JSON configuration for ContextPipelineComponent.
MemoryArtifactStoreComponent
Component wrapper for MemoryArtifactStore.
MemoryEmbeddingStoreComponent
Component wrapper for MemoryEmbeddingStore.
MemoryExecutionStoreComponent
Component wrapper for MemoryExecutionStore.
MemoryRunStoreComponent
Component wrapper for MemoryRunStore.
MemorySessionStoreComponent
Component wrapper for MemorySessionStore.
ProviderHttpComponentConfig
JSON-deserializable configuration for HTTP-backed providers like OpenAI and Anthropic. Uses plain String for the API key (instead of SecretString) so that it can be deserialised from JSON/YAML/TOML.

Enums

ComponentError
Error type for components constructed from configuration.

Functions

default_factory_registry
Returns a FactoryRegistry pre-populated with all built-in component factory invokers:
register_context_pipeline
Registers the context-pipeline factory invoker into a FactoryRegistry.
register_memory_stores
Registers all memory-store factory invokers into a FactoryRegistry.
register_providers
Registers all provider factory invokers into a FactoryRegistry.