#[non_exhaustive]pub enum ExtensionError {
AlreadyRegistered {
name: String,
},
NotFound {
name: String,
},
InUse {
name: String,
strong_count: usize,
},
LockPoisoned,
}Expand description
Errors raised by ExtensionPoint operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlreadyRegistered
Tried to register a name that is already in use.
NotFound
Tried to unregister or replace a name that is not present.
InUse
Tried to unregister a name whose strong count is greater than
one (i.e. external callers are still holding the Arc<T>).
Fields
LockPoisoned
Internal lock acquisition failed.