pub struct InvocationHandle { /* private fields */ }Expand description
Handle to a background listener task started by RuntimeInvocation::on.
Dropping this handle aborts the listener task to prevent leaks. Inner handler tasks already dispatched before drop run to completion.
Implementations
Sourceimpl InvocationHandle
impl InvocationHandle
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Returns true once the listener task has finished (completed or aborted).