RegistryError

Enum RegistryError 

#[non_exhaustive]
pub enum RegistryError { AlreadyRegistered { name: String, }, NotFound { name: String, }, MissingDependency { name: String, dep: String, }, Cycle { cycle: Vec<String>, }, Init { name: String, message: String, }, Start { name: String, message: String, }, Stop { name: String, message: String, }, Reload { name: String, message: String, }, LockPoisoned, TypeMismatch { name: String, type_id: TypeId, }, AlreadyInitialized { name: String, }, }
Errors raised by ComponentRegistry operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AlreadyRegistered

Tried to register a name that is already in use.

Fields

name: String

The conflicting name.



NotFound

Tried to unregister a name that is not present.

Fields

name: String

The missing name.



MissingDependency

A factory listed in depends_on was not registered.

Fields

name: String

The component declaring the dependency.

dep: String

The missing dependency name.



Cycle

The dependency graph contains a cycle. The first cycle found is reported as a list of node names.

Fields

cycle: Vec<String>

The cycle, in the order it was discovered.



Init

Init phase failed for a component.

Fields

name: String

Name of the failing component.

message: String

Human-readable error.



Start

Start phase failed for a component.

Fields

name: String

Name of the failing component.

message: String

Human-readable error.



Stop

Stop phase failed for a component. Other components continue to stop regardless.

Fields

name: String

Name of the failing component.

message: String

Human-readable error.



Reload

A reload (hot-swap) operation failed.

Fields

name: String

Name of the component being reloaded.

message: String

Human-readable error.



LockPoisoned

Internal lock acquisition failed.



TypeMismatch

A typed downcast failed via ComponentRegistry::get.

Fields

name: String

The name that was looked up.

type_id: TypeId

The actual TypeId of the stored instance.



AlreadyInitialized

Tried to init_all after a previous init_all already started or completed. Use explicit unregister to re-init.

Fields

name: String

The already-initialized name.