pub struct ScopeGuard { /* private fields */ }Expand description
RAII guard that pops a scope from a ScopedToolRegistry on drop.
Created by ScopedToolRegistry::push_scope_guarded. The scope is
popped when the guard is dropped, regardless of whether the scope is
still the top of the stack (non-top pops are silently ignored by
the underlying pop_scope).
Implementations
Sourceimpl ScopeGuard
impl ScopeGuard
Sourcepub fn into_inner(self) -> Arc<ScopedToolRegistry> ⓘ
pub fn into_inner(self) -> Arc<ScopedToolRegistry> ⓘ
Consumes the guard without popping. The scope remains on the stack.
Returns the underlying ScopedToolRegistry reference.