pub enum TurnAction {
Continue {
next: TurnState,
},
BreakLoop,
CompactAndRetry,
Fail {
reason: String,
},
}Expand description
Action the loop executor should take after a transition.
Variants
Continue
Proceed to the next state in the normal flow.
BreakLoop
Break the loop and complete the run successfully.
CompactAndRetry
Run compaction then retry CallingModel.
Fail
Terminate the run with an error.