AgentEvent

Enum AgentEvent 

pub enum AgentEvent {
Show 18 variants RunStarted(RunStarted), ContextBuilt(ContextBuilt), ModelStarted(ModelStarted), TextDelta(TextDelta), ToolCallStarted(ToolCallStarted), ToolCallDelta(ToolCallDelta), ToolCallCompleted(ToolCallCompleted), ToolExecutionStarted(ToolExecutionStarted), ToolExecutionFinished(ToolExecutionFinished), AssistantMessageCommitted(MessageCommitted), ToolMessageCommitted(MessageCommitted), UsageRecorded(UsageRecorded), CacheMetrics(CacheMetrics), RunCompleted(RunCompleted), RunFailed(RunFailed), RunCancelled(RunCancelled), DoomLoopDetected(DoomLoopDetected), CompactionCircuitOpened(CompactionCircuitOpened),
}
Event emitted during agent runtime execution.

Variants



RunStarted(RunStarted)

Run has started.



ContextBuilt(ContextBuilt)

Context has been built.



ModelStarted(ModelStarted)

Model call has started.



TextDelta(TextDelta)

Text delta from model.



ToolCallStarted(ToolCallStarted)

Tool call has started.



ToolCallDelta(ToolCallDelta)

Tool call arguments delta.



ToolCallCompleted(ToolCallCompleted)

Tool call has completed.



ToolExecutionStarted(ToolExecutionStarted)

Tool execution has started.



ToolExecutionFinished(ToolExecutionFinished)

Tool execution has finished.



AssistantMessageCommitted(MessageCommitted)

Assistant message has been committed to store.



ToolMessageCommitted(MessageCommitted)

Tool message has been committed to store.



UsageRecorded(UsageRecorded)

Usage has been recorded.



CacheMetrics(CacheMetrics)

Prompt cache metrics from a single model call.



RunCompleted(RunCompleted)

Run has completed successfully.



RunFailed(RunFailed)

Run has failed.



RunCancelled(RunCancelled)

Run has been cancelled.



DoomLoopDetected(DoomLoopDetected)

Doom loop has been detected.



CompactionCircuitOpened(CompactionCircuitOpened)

Compaction circuit breaker has opened due to repeated failures.

Implementations

Source

impl AgentEvent

pub fn run_id(&self) -> RunId

Returns the run identifier for any event variant without pattern matching.

pub fn is_terminal(&self) -> bool

Returns true when this event signals a terminal run state.