Token estimation using character-based heuristics.
Core functions re-exported from behest-core.
Store-dependent estimation functions are defined here.
Functions
- estimate_
content_ part_ tokens - Estimates the token count for a content part.
- estimate_
message_ tokens - Estimates the total token count for a provider
Message. - estimate_
messages_ tokens - Estimates the total token count for a slice of provider
Messages. - estimate_
record_ tokens - Estimates the token count for a store
MessageRecord. - estimate_
records_ tokens - Estimates the total token count for a slice of
MessageRecords. - estimate_
tokens - Estimates the number of tokens for a string.
- estimate_
tool_ call_ tokens - Estimates the token count for a tool call.